@@ -20,7 +20,7 @@ def deprecate(msg, level_modifier=0):
 
 
 class MigrationNotice(DeprecationWarning):
-    url = 'https://django-filter.readthedocs.io/en/master/guide/migration.html'
+    url = 'https://django-filter.readthedocs.io/en/main/guide/migration.html'
 
     def __init__(self, message):
         super().__init__('%s See: %s' % (message, self.url))
@@ -164,10 +164,18 @@ def get_field_parts(model, field_name):
             return None
 
         fields.append(field)
-        if isinstance(field, RelatedField):
-            opts = field.remote_field.model._meta
-        elif isinstance(field, ForeignObjectRel):
-            opts = field.related_model._meta
+        try:
+            if isinstance(field, RelatedField):
+                opts = field.remote_field.model._meta
+            elif isinstance(field, ForeignObjectRel):
+                opts = field.related_model._meta
+        except AttributeError:
+            # Lazy relationships are not resolved until registry is populated.
+            raise RuntimeError(
+                "Unable to resolve relationship `%s` for `%s`. Django is most "
+                "likely not initialized, and its apps registry not populated. "
+                "Ensure Django has finished setup before loading `FilterSet`s."
+                % (field_name, model._meta.label))
 
     return fields
 
@@ -309,7 +317,7 @@ def translate_validation(error_dict):
     """
     # it's necessary to lazily import the exception, as it can otherwise create
     # an import loop when importing django_filters inside the project settings.
-    from rest_framework.exceptions import ValidationError, ErrorDetail
+    from rest_framework.exceptions import ErrorDetail, ValidationError
 
     exc = OrderedDict(
         (key, [ErrorDetail(e.message % (e.params or ()), code=e.code)
